@@ -1,12 +1,12 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2022 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.41;
+use Object::Pad 0.66;
 
-package Tangence::Meta::Field 0.29;
+package Tangence::Meta::Field 0.30;
 class Tangence::Meta::Field :strict(params);
 
 =head1 NAME
@@ -45,8 +45,8 @@ Type of the field as a L<Tangence::Meta::Type> reference
 
 =cut
 
-has $name :param :reader;
-has $type :param :reader;
+field $name :param :reader;
+field $type :param :reader;
 
 =head1 ACCESSORS
 
