@@ -1,17 +1,16 @@
 package t::TestServerClient;
 
-use v5.14;
+use v5.26;
 use warnings;
+use experimental 'signatures';
 
 use Exporter 'import';
 our @EXPORT = qw( make_serverclient );
 
 use Scalar::Util qw( weaken );
 
-sub make_serverclient
+sub make_serverclient ( $registry )
 {
-   my ( $registry ) = @_;
-
    my $server = TestServer->new();
    my $client = TestClient->new();
 
@@ -33,10 +32,8 @@ sub new
    return bless {}, shift;
 }
 
-sub tangence_write
+sub tangence_write ( $self, $message )
 {
-   my $self = shift;
-   my ( $message ) = @_;
    $self->{client}->tangence_readfrom( $message );
    length($message) == 0 or die "Client failed to read all Server wrote";
 }
@@ -52,10 +49,8 @@ sub new
    return $self;
 }
 
-sub tangence_write
+sub tangence_write ( $self, $message )
 {
-   my $self = shift;
-   my ( $message ) = @_;
    $self->{server}->tangence_readfrom( $message );
    length($message) == 0 or die "Server failed to read all Client wrote";
 }
